% GRAPHS.m
%
% Computes rational expectations solution to Ireland's (2004) model and
% uses the solution to plot linear aggregate demand and aggregate
% supply curves in output growth-inflation space.

solmat

shocks=1; % if 1, draw curves for shock processes
estimated=1; % if 1, draw observed data points and curves through those points

samplesize = 200;      
gmin = -2;%-.02; %Change this depending on the scale of the graph
gmax = 2;%.02; %Change this depending on the scale of the graph
step = .0005;
gvec = gmin:step:gmax;
[rows cols] = size(gvec); 

g_ssvec = (g_ss)*ones(rows,cols);
ppi_ssvec = (ppi_ss)*ones(rows,cols);

% Create tensors to store demand and supply curves
ppi_ad_ss = zeros(rows,cols,samplesize);
ppi_as_ss = zeros(rows,cols,samplesize);

for t = 1:samplesize
    ppi_ad_ss(:,:,t) = ad(gvec,ad_slope,0,ad_constant);
    ppi_as_ss(:,:,t) = as(gvec,as_slope,0,as_constant);
end

figure; plot(gvec,ppi_ssvec); % Plots the steady-state curves
hold on;
line([g_ss g_ss],[-4 4])
plot(gvec,ppi_as_ss(:,:,1));
plot(gvec,ppi_ad_ss(:,:,1));
title('Steady State')
%xlim([0 1])
%ylim([0 1])

if shocks
ppi_ad_eps_e = zeros(rows,cols,samplesize);
ppi_as_eps_e = zeros(rows,cols,samplesize);
ppi_ad_eps_a = zeros(rows,cols,samplesize);
ppi_as_eps_a = zeros(rows,cols,samplesize);
ppi_ad_eps_z = zeros(rows,cols,samplesize);
ppi_as_eps_z = zeros(rows,cols,samplesize);
ppi_ad_eps_r = zeros(rows,cols,samplesize);
ppi_as_eps_r = zeros(rows,cols,samplesize);

ppi_eps_e = (ppihat_eps_e + ones(samplesize,1)*ppi_ss);
g_eps_e = (ghat_eps_e + ones(samplesize,1)*g_ss);

ppi_eps_a = (ppihat_eps_a + ones(samplesize,1)*ppi_ss);
g_eps_a = (ghat_eps_a + ones(samplesize,1)*g_ss);

ppi_eps_z = (ppihat_eps_z + ones(samplesize,1)*ppi_ss);
g_eps_z = (ghat_eps_z + ones(samplesize,1)*g_ss);

ppi_eps_r = (ppihat_eps_r + ones(samplesize,1)*ppi_ss);
g_eps_r = (ghat_eps_r + ones(samplesize,1)*g_ss);

for t = 1:samplesize
    ppi_ad_eps_e(:,:,t) = ad(gvec,ad_slope,adt_eps_e(t),ad_constant);
    ppi_as_eps_e(:,:,t) = as(gvec,as_slope,ast_eps_e(t),as_constant);
    ppi_ad_eps_a(:,:,t) = ad(gvec,ad_slope,adt_eps_a(t),ad_constant);
    ppi_as_eps_a(:,:,t) = as(gvec,as_slope,ast_eps_a(t),as_constant);
    ppi_ad_eps_z(:,:,t) = ad(gvec,ad_slope,adt_eps_z(t),ad_constant);
    ppi_as_eps_z(:,:,t) = as(gvec,as_slope,ast_eps_z(t),as_constant);
    ppi_ad_eps_r(:,:,t) = ad(gvec,ad_slope,adt_eps_r(t),ad_constant);
    ppi_as_eps_r(:,:,t) = as(gvec,as_slope,ast_eps_r(t),as_constant);
end


from = 1; % First period to draw curves for
to = 5; % Second period to draw curves for

figure; plot(gvec,ppi_ssvec);
hold on;
line([g_ss g_ss],[-4 4])
plot(gvec,ppi_as_eps_e(:,:,from));
plot(gvec,ppi_as_eps_e(:,:,to),'r');
plot(gvec,ppi_ad_eps_e(:,:,from),':');
plot(gvec,ppi_ad_eps_e(:,:,to),':r');
title('Shock e')
scatter(g_eps_e,ppi_eps_e);

figure; plot(gvec,ppi_ssvec);
hold on;
line([g_ss g_ss],[-4 4])
plot(gvec,ppi_as_eps_a(:,:,from));
plot(gvec,ppi_as_eps_a(:,:,to),'r');
plot(gvec,ppi_ad_eps_a(:,:,from),':');
plot(gvec,ppi_ad_eps_a(:,:,to),':r');
title('Shock a')
scatter(g_eps_a,ppi_eps_a);

figure; plot(gvec,ppi_ssvec);
hold on;
line([g_ss g_ss],[-4 4])
plot(gvec,ppi_as_eps_z(:,:,from));
plot(gvec,ppi_as_eps_z(:,:,to),'r');
plot(gvec,ppi_ad_eps_z(:,:,from),':');
plot(gvec,ppi_ad_eps_z(:,:,to),':r');
title('Shock z')
scatter(g_eps_z,ppi_eps_z);

figure; plot(gvec,ppi_ssvec);
hold on;
line([g_ss g_ss],[-4 4])
%line([0.999 0.9995], [ad(0.999,ad_slope,adt_eps_r(from),ad_constant) ad(0.9995,ad_slope,adt_eps_r(from),ad_constant)]);
plot(gvec,ppi_as_eps_r(:,:,from));
plot(gvec,ppi_as_eps_r(:,:,to),'r');
plot(gvec,ppi_ad_eps_r(:,:,from),':');
plot(gvec,ppi_ad_eps_r(:,:,to),':r');
title('Shock r')
scatter(g_eps_r,ppi_eps_r);
end

if estimated % For drawing curves with estimates
    first = dates.Q200700; %2007Q1 Coloured scatter
    second = dates.Q201050; %2010Q3 Coloured scatter
    period1 = dates.Q200725; %2007Q2 drawing ASAD for this period
    period2 = dates.Q200875; %2008Q4 drawing ASAD for this period
    
    samplesize=length(ppihat);
    
    ppi_ad_data = zeros(rows,cols,samplesize);
    ppi_as_data = zeros(rows,cols,samplesize);
        
        for t = dates.Q199000:dates.Q201050
            ppi_ad_data(:,:,t) = ad(gvec,ad_slope,oo_.SmoothedVariables.adt(t,1),ad_constant);
            ppi_as_data(:,:,t) = as(gvec,as_slope,oo_.SmoothedVariables.ast(t,1),as_constant);
        end
     
    figure; plot(gvec,ppi_ssvec,'r','LineWidth',2);
    hold on;
    line([g_ss g_ss],[-4 4],'Color','r','LineWidth',2)
    plot(gvec(1,5991:6021),ppi_as_data(:,5991:6021,period1));
    plot(gvec(1,1:6016),ppi_ad_data(:,1:6016,period1));
    plot(gvec(1,1:5981),ppi_as_data(:,1:5981,period2),'r');
    plot(gvec(1,5959:5961),ppi_ad_data(:,5959:5961,period2),'r');    
    scatter(ghat(dates.Q199000:dates.Q201050,1)+g_ss,ppihat(dates.Q199000:dates.Q201050,1)+ppi_ss);
    for i=first:second
        Y=scatter(ghat(first:second,1)+g_ss,ppihat(first:second,1)+ppi_ss,'filled');
    end
    for i=first:(second-1)
        Y=line([ghat(i,1)+g_ss,ghat(i+1,1)+g_ss],[ppihat(i,1)+ppi_ss,ppihat(i+1,1)+ppi_ss]);
    end
    title('History')
    %ylim([-1 2])
    
    asthistory = [ ...
        oo_.SmoothedVariables.ast(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.astppihat(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.astyhat(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.astz(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.asta(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.aste(dates.Q200800:dates.Q201050,1) ...
        ]'; % For table
    
    adthistory = [ ...
        oo_.SmoothedVariables.adt(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.adtx(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.adtppihat(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.adtyhat(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.adtrhat(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.adtz(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.adta(dates.Q200800:dates.Q201050,1) ...
        oo_.SmoothedVariables.adteps_r(dates.Q200800:dates.Q201050,1) ...
        ]'; % For table
    
end

ast_eps_r_contributions = [astppihat_eps_r astyhat_eps_r asta_eps_r aste_eps_r astz_eps_r]./[ast_eps_r*ones(1,5)];
ast_eps_a_contributions = [astppihat_eps_a astyhat_eps_a asta_eps_a aste_eps_a astz_eps_a]./[ast_eps_a*ones(1,5)];
ast_eps_e_contributions = [astppihat_eps_e astyhat_eps_e asta_eps_e aste_eps_e astz_eps_e]./[ast_eps_e*ones(1,5)];
ast_eps_z_contributions = [astppihat_eps_z astyhat_eps_z asta_eps_z aste_eps_z astz_eps_z]./[ast_eps_z*ones(1,5)];

adt_eps_r_contributions = [adtx_eps_r adtppihat_eps_r adtyhat_eps_r adtrhat_eps_r adtz_eps_r adta_eps_r adteps_r_eps_r]./[adt_eps_r*ones(1,7)];
adt_eps_a_contributions = [adtx_eps_a adtppihat_eps_a adtyhat_eps_a adtrhat_eps_a adtz_eps_a adta_eps_a adteps_r_eps_a]./[adt_eps_a*ones(1,7)];
adt_eps_e_contributions = [adtx_eps_e adtppihat_eps_e adtyhat_eps_e adtrhat_eps_e adtz_eps_e adta_eps_e adteps_r_eps_e]./[adt_eps_e*ones(1,7)];
adt_eps_z_contributions = [adtx_eps_z adtppihat_eps_z adtyhat_eps_z adtrhat_eps_z adtz_eps_z adta_eps_z adteps_r_eps_z]./[adt_eps_z*ones(1,7)];

adt_contributions = [adt_eps_r_contributions(1,:)' adt_eps_a_contributions(1,:)' adt_eps_e_contributions(1,:)' adt_eps_z_contributions(1,:)'];
ast_contributions = [ast_eps_r_contributions(1,:)' ast_eps_a_contributions(1,:)' ast_eps_e_contributions(1,:)' ast_eps_z_contributions(1,:)'];